@@ -1,6 +1,7 @@
 #include <pthread.h>
 #include <semaphore.h>
 #include <stdio.h>
+#include <string.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <libnet.h>
@@ -680,7 +681,7 @@ nethost *receive_arp_replies ()
 	    printf ("%02x:%02x:%02x:%02x:%02x:%02x\n%02x:%02x:%02x:%02x:%02x:%02x\n", cycle->hardware_address[0], cycle->hardware_address[1], cycle->hardware_address[2], cycle->hardware_address[3], cycle->hardware_address[4], cycle->hardware_address[5], arp_header->ar_sha[0], arp_header->ar_sha[1], arp_header->ar_sha[2], arp_header->ar_sha[3], arp_header->ar_sha[4], arp_header->ar_sha[5]);
 
 	  /* ...check whether the harware address matches... */
-	  if (strncmp (cycle->hardware_address, arp_header->ar_sha, 6))
+	  if (memcmp (cycle->hardware_address, arp_header->ar_sha, 6))
 	    continue;
 
 	  /* ...log the match if requested to... */
